@@ -31,7 +31,7 @@ class SearchEngine:
         t.start()
         sleep(1)
         if self.send_flag[0]:
-            print("receiving data, please don't stop the process until \"receiving end\" appears in terminal")
+            print("receiving data, please don't stop the process until \"extracting end\" appears in terminal")
             while self.send_flag[0]:
                 sleep(1)
 
@@ -55,7 +55,7 @@ class SearchEngine:
             new_query["authors"] = query["query_text"]["authors"].lower()
             new_query["abstract"] = query["query_text"]["abstract"].lower()
             new_query["pdfText"] = query["query_text"]["content"].lower()
-            new_query["year"] = query["query_text"]["year"].lower()
+            # new_query["year"] = query["query_text"]["year"].lower()
 
             complete_new_query["type"] = query["type"]
             complete_new_query["top_number"] = query["top_number"]
